@@ -5,7 +5,7 @@ import logging
 
 from .discover import discover
 from .environment import Environment
-from .verify import generate_hash_comment
+from .verify import generate_robust_hash_comment
 from .features import FEATURES
 from .deduplicate import PackageDeduplicator
 
@@ -38,6 +38,6 @@ def compile_topologically(env_confs, deduplicator):
         env = Environment(in_path=conf['in_path'], deduplicator=deduplicator)
         if env.maybe_create_lockfile():
             # Only munge lockfile if it was written.
-            header_text = generate_hash_comment(env.infile) + FEATURES.get_header_text()
+            header_text = generate_robust_hash_comment(env.infile) + FEATURES.get_header_text()
             env.replace_header(header_text)
             env.add_references(conf['refs'])
